@@ -4,6 +4,7 @@ class Color:
         self.RED = '\033[31m'
         self.GREEN = '\033[32m'
         self.YELLOW = '\033[33m'
+        self.BLUE = '\033[34m'
         self.END = '\033[0m'
     
     def red(self, text):
@@ -15,3 +16,5 @@ class Color:
     def green(self, text):
         print(self.GREEN + text + self.END)
 
+    def blue(self, text):
+        print(self.BLUE + text + self.END)
\ No newline at end of file
